@@ -13,36 +13,28 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import csv
 import codecs
-import cStringIO
+import csv
 
 # A special CSV writer which will write rows to TSV file "f", which is encoded in utf-8.
 # this is necessary because the values in druid are not all ASCII.
 
 
-class UnicodeWriter:
+class UnicodeWriter(object):
 
     # delimiter="\t"
     def __init__(self, f, dialect="excel-tab", encoding="utf-8", **kwds):
-        # Redirect output to a queue
-        self.queue = cStringIO.StringIO()
-        self.writer = csv.writer(self.queue, dialect=dialect, **kwds)
         self.stream = f
+        self.writer = csv.writer(self.stream, dialect=dialect, **kwds)
         self.encoder = codecs.getincrementalencoder(encoding)()
 
+    @staticmethod
+    def __encode(data):
+        return str(data) if isinstance(data, str) else data
+
     def writerow(self, row):
-        self.writer.writerow(
-            [s.encode("utf-8") if isinstance(s, unicode) else s for s in row])
-        # Fetch UTF-8 output from the queue ...
-        data = self.queue.getvalue()
-        data = data.decode("utf-8")
-        # ... and reencode it into the target encoding
-        data = self.encoder.encode(data)
-        # write to the target stream
-        self.stream.write(data)
-        # empty queue
-        self.queue.truncate(0)
+        row = [self.__encode(s) for s in row]
+        self.writer.writerow(row)
 
     def writerows(self, rows):
         for row in rows:
